wepy.work\_mapper package
=========================

.. automodule:: wepy.work_mapper
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

.. toctree::

   wepy.work_mapper.mapper
   wepy.work_mapper.worker
